Trait tpfs_krypt::Signing

source ·
pub trait Signing: Send + Sync {
    // Required method
    fn sign(
        &self,
        address: &KeyIdentifier,
        message: &[u8]
    ) -> Result<Box<dyn Signature>>;
}
A trait that specifies any of the signing portions which is shared publicly via KeyManagement trait.

Required Methods

source

fn sign( &self, address: &KeyIdentifier, message: &[u8] ) -> Result<Box<dyn Signature>>

Signs the message using the keypair associated with the provided address, if found.

Implementors

source

impl<T: KeyStorage> Signing for T